@@ -300,39 +300,64 @@ class WordPressAutoUpdater {
     
     /**
      * Process updates for a single site
+     * @param array $site The site data
+     * @param string|null $updateType Specific update type to run (core|plugins|themes), or null for all
      */
-    public function processSite($site) {
+    public function processSite($site, $updateType = null) {
         $this->log("Processing site: {$site['domain']} (ID: {$site['id']})", 'INFO');
-        
+
         $success = true;
-        
+
         // Create backup if needed
         if (!$this->createBackup($site)) {
             $this->log("Skipping updates for {$site['domain']} due to backup failure", 'ERROR');
             return false;
         }
-        
-        // Update core
-        if (!$this->updateCore($site)) {
-            $success = false;
+
+        // If a specific update type is specified, only run that type
+        // Otherwise, run all enabled update types for the site
+        if ($updateType) {
+            switch ($updateType) {
+                case 'core':
+                    if (!$this->updateCore($site)) {
+                        $success = false;
+                    }
+                    break;
+                case 'plugins':
+                    if (!$this->updatePlugins($site)) {
+                        $success = false;
+                    }
+                    break;
+                case 'themes':
+                    if (!$this->updateThemes($site)) {
+                        $success = false;
+                    }
+                    break;
+            }
+        } else {
+            // Run all update types that are enabled for the site
+            // Update core
+            if (!$this->updateCore($site)) {
+                $success = false;
+            }
+
+            // Update plugins
+            if (!$this->updatePlugins($site)) {
+                $success = false;
+            }
+
+            // Update themes
+            if (!$this->updateThemes($site)) {
+                $success = false;
+            }
         }
-        
-        // Update plugins
-        if (!$this->updatePlugins($site)) {
-            $success = false;
-        }
-        
-        // Update themes
-        if (!$this->updateThemes($site)) {
-            $success = false;
-        }
-        
+
         if ($success) {
             $this->log("All updates completed successfully for {$site['domain']}", 'SUCCESS');
         } else {
             $this->log("Some updates failed for {$site['domain']}", 'WARNING');
         }
-        
+
         return $success;
     }
     
@@ -353,12 +378,12 @@ class WordPressAutoUpdater {
         $failureCount = 0;
         
         foreach ($sites as $site) {
-            if ($this->processSite($site)) {
+            if ($this->processSite($site, $updateType)) {
                 $successCount++;
             } else {
                 $failureCount++;
             }
-            
+
             // Add a small delay between sites to prevent overwhelming the system
             if (!$this->dryRun) {
                 sleep(2);
