@@ -15,6 +15,7 @@ class permission_manager {
         'database-management' => array('all'), // All authenticated users
         'postgresql-management' => array('all'), // All authenticated users
         'user-management' => array('root'), // Only root
+        'delegated-users' => array('all'), // All users can manage their own delegated users
         'security-management' => array('root'), // Only root
         'announcements-management' => array('root'), // Only root
         'update-management' => array('root'), // Only root
@@ -89,6 +90,11 @@ class permission_manager {
      * @return bool True if user has permission, false otherwise
      */
     public function check_page_permission($user, $page) {
+        // Check if this is a delegated user
+        if (isset($_SESSION['user_type']) && $_SESSION['user_type'] === 'delegated') {
+            return $this->check_delegated_page_permission($user, $page);
+        }
+        
         // Check if page exists in permissions
         if (!isset($this->page_permissions[$page])) {
             // Unknown page - deny access
@@ -110,6 +116,63 @@ class permission_manager {
         return false;
     }
     
+    /**
+     * Check if delegated user has permission to access a page
+     * 
+     * @param string $user The delegated username
+     * @param string $page The page name
+     * @return bool True if user has permission, false otherwise
+     */
+    public function check_delegated_page_permission($user, $page) {
+        if (!isset($_SESSION['delegated_user_id'])) {
+            return false;
+        }
+        
+        // Map page names to delegated user permission flags
+        $page_permission_map = [
+            'domains' => 'can_manage_domains',
+            'sites' => 'can_manage_sites',
+            'database-management' => 'can_manage_databases',
+            'postgresql-management' => 'can_manage_databases',
+            'email-management' => 'can_manage_email',
+            'backups' => 'can_manage_backups',
+            'terminal' => 'can_view_terminal',
+            'wordpress' => 'can_manage_wordpress',
+            'dashboard' => true, // All delegated users can access dashboard
+        ];
+        
+        // Check if page is explicitly not allowed for delegated users
+        $restricted_pages = ['user-management', 'security-management', 'announcements-management', 
+                           'update-management', 'docker-management', 'user-resources', 'server-settings'];
+        
+        if (in_array($page, $restricted_pages)) {
+            return false;
+        }
+        
+        // Special case: delegated users can access the delegated-users page (to view their own info)
+        // but with limited functionality
+        if ($page === 'delegated-users') {
+            return true;
+        }
+        
+        // If page is not mapped, allow access (for general pages)
+        if (!isset($page_permission_map[$page])) {
+            return true;
+        }
+        
+        // If mapped to true, always allow
+        if ($page_permission_map[$page] === true) {
+            return true;
+        }
+        
+        // Check delegated user permissions
+        require_once('/docker/whp/web/libs/delegated_user_manager.php');
+        $delegatedUserManager = new DelegatedUserManager();
+        
+        $permission_name = str_replace('can_', '', $page_permission_map[$page]);
+        return $delegatedUserManager->hasPermission($_SESSION['delegated_user_id'], $permission_name);
+    }
+    
     /**
      * Check if user has permission to access an API
      * 
@@ -118,6 +181,11 @@ class permission_manager {
      * @return bool True if user has permission, false otherwise
      */
     public function check_api_permission($user, $api) {
+        // Check if this is a delegated user
+        if (isset($_SESSION['user_type']) && $_SESSION['user_type'] === 'delegated') {
+            return $this->check_delegated_api_permission($user, $api);
+        }
+        
         // Check if API exists in permissions
         if (!isset($this->api_permissions[$api])) {
             // Unknown API - deny access
@@ -139,6 +207,56 @@ class permission_manager {
         return false;
     }
     
+    /**
+     * Check if delegated user has permission to access an API
+     * 
+     * @param string $user The delegated username
+     * @param string $api The API name
+     * @return bool True if user has permission, false otherwise
+     */
+    public function check_delegated_api_permission($user, $api) {
+        if (!isset($_SESSION['delegated_user_id'])) {
+            return false;
+        }
+        
+        // Map API names to delegated user permission flags
+        $api_permission_map = [
+            'domains' => 'can_manage_domains',
+            'sites' => 'can_manage_sites',
+            'database-management' => 'can_manage_databases',
+            'postgresql-management' => 'can_manage_databases',
+            'email-management' => 'can_manage_email',
+            'backup-actions' => 'can_manage_backups',
+            'terminal' => 'can_view_terminal',
+            'wordpress-ajax' => 'can_manage_wordpress',
+        ];
+        
+        // Check if API is explicitly not allowed for delegated users
+        $restricted_apis = ['user-management', 'security-management', 'announcements-management', 
+                          'update-management', 'docker-management', 'user-resources'];
+        
+        if (in_array($api, $restricted_apis)) {
+            return false;
+        }
+        
+        // Allow delegated user management API for the delegated user itself
+        if ($api === 'delegated-user-management') {
+            return true;
+        }
+        
+        // If API is not mapped, deny access for security
+        if (!isset($api_permission_map[$api])) {
+            return false;
+        }
+        
+        // Check delegated user permissions
+        require_once('/docker/whp/web/libs/delegated_user_manager.php');
+        $delegatedUserManager = new DelegatedUserManager();
+        
+        $permission_name = str_replace('can_', '', $api_permission_map[$api]);
+        return $delegatedUserManager->hasPermission($_SESSION['delegated_user_id'], $permission_name);
+    }
+    
     /**
      * Log an access attempt
      * 
