@@ -973,6 +973,11 @@ document.getElementById('scheduleForm').addEventListener('submit', function(e) {
     
     const formData = new FormData(this);
     formData.append('action', document.getElementById('scheduleId').value ? 'update_schedule' : 'create_schedule');
+    
+    // Explicitly add checkbox value since unchecked checkboxes aren't included in FormData
+    if (!formData.has('is_active')) {
+        formData.append('is_active', '0');
+    }
     // CSRF token will be added via header
     
     fetch('api/backup-actions.php', {
