@@ -23,10 +23,41 @@ function process_pending_backups() {
         $mysql = new mysqlmgmt();
         $db = $mysql->getMySQLConnection();
         $db->exec("USE whp");
-        
-        // Get pending backups
-        $stmt = $db->prepare("SELECT id FROM backup_history WHERE status = 'pending' ORDER BY started_at ASC LIMIT 5");
+
+        // Get maximum concurrent backups from settings file
+        $max_concurrent = 2; // Default value
+        if (file_exists('/docker/whp/settings.json')) {
+            $settings = json_decode(file_get_contents('/docker/whp/settings.json'), true);
+            if ($settings && isset($settings['backup_max_concurrent'])) {
+                $max_concurrent = intval($settings['backup_max_concurrent']);
+                if ($max_concurrent < 1 || $max_concurrent > 10) {
+                    $max_concurrent = 2; // Fallback to default if invalid
+                }
+            }
+        }
+
+        log_message("Using maximum concurrent backups: $max_concurrent");
+
+        // Count currently running backups
+        $stmt = $db->prepare("SELECT COUNT(*) FROM backup_history WHERE status = 'processing'");
         $stmt->execute();
+        $running_count = $stmt->fetchColumn();
+
+        log_message("Currently running backups: $running_count");
+
+        // Calculate how many new backups we can start
+        $available_slots = $max_concurrent - $running_count;
+
+        if ($available_slots <= 0) {
+            log_message("Maximum concurrent backups reached ($max_concurrent). No new backups can be started.");
+            return;
+        }
+
+        log_message("Available backup slots: $available_slots");
+
+        // Get pending backups (limit to available slots)
+        $stmt = $db->prepare("SELECT id FROM backup_history WHERE status = 'pending' ORDER BY started_at ASC LIMIT ?");
+        $stmt->execute([$available_slots]);
         $backups = $stmt->fetchAll(PDO::FETCH_ASSOC);
         
         if (empty($backups)) {
